import base64

def image_to_base64(image_path: str) -> str:
    """Reads an image file and returns it as a Base64 encoded string."""
    try:
        with open(image_path, "rb") as image_file:
            return base64.b64encode(image_file.read()).decode('utf-8')
    except FileNotFoundError:
        raise FileNotFoundError(f"Image file not found at path: {image_path}")


from .resources.auth import AuthResource

class BioLogreenClient:
    """The main client for interacting with the Bio-Logreen API."""

    def __init__(self, api_key: str, base_url: str = "https://api.biologreen.com/v1"):
        if not api_key:
            raise ValueError("An API key is required to use the Bio-Logreen SDK.")
        
        self.api_key = api_key
        self.base_url = base_url
        
        # Initialize all the different parts of the API
        self.auth = AuthResource(self)



from setuptools import setup, find_packages

setup(
    name="biologreen",
    version="0.1.0",
    author="AtuhurraSolomon", 
    author_email="atuhurrasolomon47@gmail.com", 
    description="The official Python SDK for the Bio-Logreen Facial Authentication API.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/AtuhurraSolomon/biologreen-python-sdk", 
    packages=find_packages(),
    install_requires=[
        "requests>=2.20.0",
        "pydantic>=2.0.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)
